@@ -14,13 +14,16 @@ __title__ = "askitsu"
 __author__ = "ShomyKohai"
 __license__ = "MIT"
 __copyright__ = "Copyright 2022-present ShomyKohai"
-__version__ = "0.5.0"
+__version__ = "1.0.0"
+
+# __all__
 
-from .anime import *
 from .client import *
-from .character import *
-from .core import *
 from .error import *
-from .images import *
-from .manga import *
-from .users import *
+from .models.anime import *
+from .models.character import *
+from .models.core import *
+from .models.enums import *
+from .models.images import *
+from .models.manga import *
+from .models.users import *
